@@ -5,18 +5,20 @@ use strict;
 use warnings;
 use parent qw/Exporter/;
 
+use Carp qw/croak/;
+
 use IO::Uncompress::Brotli;
 
 our @EXPORT = qw/bro/;
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.010';
 
 my %BROTLI_ENCODER_MODE = ( generic => 0, text => 1, font => 2 );
 sub mode {
     my ($self, $mode) = @_;
 
-    die "Invalid encoder mode"
+    croak 'Invalid encoder mode'
         unless $BROTLI_ENCODER_MODE{$mode};
 
     _mode($$self, $mode)
@@ -63,10 +65,12 @@ function.
 
 =over
 
-=item B<bro>(I<$input>)
+=item B<bro>(I<$input>, I<$quality>, I<$window>)
 
 Takes a whole uncompressed buffer as input and returns the compressed
-data.
+data using the supplied quality and window parameters. If quality and
+window parameters are not supplied, default values are used (as
+described under the object-oriented interface).
 
 Exported by default.
 
